| Home | Libraries | People | FAQ | More

## Removed from library: Standard Integer Types

The Boost.Config module provides the typedefs useful for writing portable code that requires certain integer widths.

| Copyright © 2001-2009 Beman Dawes, Daryle Walker, Gennaro Prota, John Maddock Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)